tslumen.cli package
===================

.. automodule:: tslumen.cli
   :members:
   :undoc-members:
   :show-inheritance:

tslumen.cli.readers module
--------------------------

.. automodule:: tslumen.cli.readers
   :members:
   :undoc-members:
   :show-inheritance:
